@@ -22,7 +22,6 @@ class KConfigGroup
 #include "vncsshtunnelthread.h"
 #endif
 
-#include <QClipboard>
 #include <QMap>
 
 extern "C" {
@@ -62,20 +61,18 @@ public Q_SLOTS:
 
 protected:
     void paintEvent(QPaintEvent *event) override;
-    bool event(QEvent *event) override;
     void resizeEvent(QResizeEvent *event) override;
-    bool eventFilter(QObject *obj, QEvent *event) override;
-    void focusOutEvent(QFocusEvent *event) override;
+    void handleKeyEvent(QKeyEvent *event) override;
+    void handleWheelEvent(QWheelEvent *event) override;
+    void handleMouseEvent(QMouseEvent *event) override;
+    void handleLocalClipboardChanged(const QMimeData *data) override;
 
 private:
     VncClientThread vncThread;
-    QClipboard *m_clipboard;
     bool m_initDone;
     int m_buttonMask;
-    QMap<unsigned int, bool> m_mods;
     bool m_quitFlag;
     bool m_firstPasswordTry;
-    bool m_dontSendClipboard;
     qreal m_horizontalFactor;
     qreal m_verticalFactor;
     int m_wheelRemainderV;
@@ -92,11 +89,6 @@ private:
     void saveWalletSshPassword();
 #endif
 
-    void keyEventHandler(QKeyEvent *e);
-    void unpressModifiers();
-    void wheelEventHandler(QWheelEvent *event);
-    void mouseEventHandler(QMouseEvent *event);
-
 private Q_SLOTS:
     void updateImage(int x, int y, int w, int h);
     void setCut(const QString &text);
@@ -106,7 +98,6 @@ private Q_SLOTS:
 #endif
     void outputErrorMessage(const QString &message);
     void sshErrorMessage(const QString &message);
-    void clipboardDataChanged();
 };
 
 #endif
